@@ -251,7 +251,7 @@ if (nlev==2) {
    treat.modelid <- update.formula(treat.model,.~.+cluster(id))
    treat <- mlogit(treat.modelid,data)
    iidalpha <- lava::iid(treat)
-   pal <- predictmlogit(treat,data,se=0,response=FALSE)
+   pal <- predict(treat,data,se=0,response=FALSE)
    ppp <- (pal/pal[,1])
    spp <- 1/pal[,1]
 }
