@@ -1,23 +1,22 @@
 ##' CIF regression
 ##'
-##' CIF logistic for propodds=1 default
-##' CIF Fine-Gray (cloglog) regression for propodds=NULL
+##' CIF logistic-link for propodds=1 default and CIF Fine-Gray (cloglog) regression for propodds=NULL. The
+##' FG model can also be called using the cifregFG function that has propodds=NULL.
 ##'
 ##' For FG model:
 ##' \deqn{
 ##' \int (X - E ) Y_1(t) w(t) dM_1
 ##' }
-##' is computed and summed over clusters  and returned multiplied with inverse
-##' of second derivative as iid.naive. Where \deqn{w(t) = G(t) (I(T_i \wedge t < C_i)/G_c(T_i \wedge t))} and
-##' \deqn{E(t) = S_1(t)/S_0(t)} and \deqn{S_j(t) = \sum X_i^j Y_{i1}(t) w_i(t) \exp(X_i^T \beta)}
-##'
+##' is computed and summed over clusters and returned multiplied with inverse
+##' of second derivative as iid.naive. Here \deqn{w(t) = G(t) (I(T_i \wedge t < C_i)/G_c(T_i \wedge t))} and
+##' \deqn{E(t) = S_1(t)/S_0(t)} and \deqn{S_j(t) = \sum X_i^j Y_{i1}(t) w_i(t) \exp(X_i^T \beta)}.
 ##'
 ##' The iid decomposition of the beta's, however, also have a censoring term that is also
-##' is computed and added to UUiid (still scaled with inverse second derivative)
+##' is computed and added (still scaled with inverse second derivative)
 ##' \deqn{
 ##' \int (X - E ) Y_1(t) w(t) dM_1 + \int q(s)/p(s) dM_c
 ##' }
-##' and returned as iid
+##' and returned as the iid 
 ##'
 ##' For logistic link standard errors are slightly to small since uncertainty from recursive baseline is not considered, so for smaller
 ##' data-sets it is recommended to use the prop.odds.subdist of timereg that is also more efficient due to use of different weights for
@@ -25,117 +24,178 @@
 ##'
 ##' @param formula formula with 'Event' outcome
 ##' @param data data frame
+##' @param propodds to fit logit link model, and propodds=NULL to fit Fine-Gray model
 ##' @param cause of interest
 ##' @param cens.code code of censoring
-##' @param cens.model for stratified Cox model without covariates
-##' @param offset offsets for FG  model
-##' @param weights weights for FG score equations
-##' @param Gc censoring weights for time argument, default is to calculate these with a Kaplan-Meier estimator, should then give G_c(T_i-)
-##' @param propodds 1 is logistic model, NULL is fine-gray model
-##' @param ... Additional arguments to lower level funtions
+##' @param no.codes certain event codes to be ignored when finding competing causes
+##' @param ... Additional arguments to recreg 
 ##' @author Thomas Scheike
 ##' @examples
 ##' ## data with no ties
+##' library(mets)
 ##' data(bmt,package="timereg")
 ##' bmt$time <- bmt$time+runif(nrow(bmt))*0.01
 ##' bmt$id <- 1:nrow(bmt)
 ##'
 ##' ## logistic link  OR interpretation
-##' ll=cifreg(Event(time,cause)~tcell+platelet+age,data=bmt,cause=1)
-##' summary(ll)
-##' plot(ll)
+##' or=cifreg(Event(time,cause)~tcell+platelet+age,data=bmt,cause=1)
+##' summary(or)
+##' par(mfrow=c(1,2))
+##' plot(or)
 ##' nd <- data.frame(tcell=c(1,0),platelet=0,age=0)
-##' pll <- predict(ll,nd)
-##' plot(pll)
+##' por <- predict(or,nd)
+##' plot(por)
 ##'
 ##' ## Fine-Gray model
-##' fg=cifreg(Event(time,cause)~tcell+platelet+age,data=bmt,cause=1,propodds=NULL)
+##' fg=cifregFG(Event(time,cause)~tcell+platelet+age,data=bmt,cause=1)
 ##' summary(fg)
 ##' plot(fg)
 ##' nd <- data.frame(tcell=c(1,0),platelet=0,age=0)
-##' pfg <- predict(fg,nd)
-##' plot(pfg)
-##'
-##' sfg <- cifreg(Event(time,cause)~strata(tcell)+platelet+age,data=bmt,cause=1,propodds=NULL)
+##' pfg <- predict(fg,nd,se=1)
+##' plot(pfg,se=1)
+##' 
+##' ## not run to avoid timing issues
+##' ## gofFG(Event(time,cause)~tcell+platelet+age,data=bmt,cause=1)
+##' 
+##' sfg <- cifregFG(Event(time,cause)~strata(tcell)+platelet+age,data=bmt,cause=1)
 ##' summary(sfg)
 ##' plot(sfg)
 ##'
 ##' ### predictions with CI based on iid decomposition of baseline and beta
-##' fg <- cifreg(Event(time,cause)~tcell+platelet+age,data=bmt,cause=1,propodds=NULL,cox.prep=TRUE)
-##' Biid <- mets:::iid.baseline.cifreg(fg,time=20)
-##' FGprediid(Biid,bmt[1:5,])
-##'
-##' @aliases vecAllStrata diffstrata iid.baseline.cifreg FGprediid indexstratarightR
+##' ### these are used in the predict function above
+##' fg <- cifregFG(Event(time,cause)~tcell+platelet+age,data=bmt,cause=1)
+##' Biid <- IIDbaseline.cifreg(fg,time=20)
+##' pfg1 <- FGprediid(Biid,nd)
+##' pfg1
+##' @aliases vecAllStrata diffstrata IIDbaseline.cifreg FGprediid indexstratarightR gofFG cifregO cifregFG IIDbaseline.cifregO
 ##' @export
-cifreg <- function(formula,data=data,cause=1,cens.code=0,cens.model=~1,
-            weights=NULL,offset=NULL,Gc=NULL,propodds=1,...)
+cifreg  <- function(formula,data,propodds=1,cause=1,cens.code=0,no.codes=NULL,...)
 {# {{{
-    cl <- match.call()# {{{
+    cl <- match.call()
     m <- match.call(expand.dots = TRUE)[1:3]
-    special <- c("strata", "cluster","offset")
+    special <- c("strata", "cluster","offset","strataAugment")
     Terms <- terms(formula, special, data = data)
     m$formula <- Terms
     m[[1]] <- as.name("model.frame")
     m <- eval(m, parent.frame())
     Y <- model.extract(m, "response")
-    if (!inherits(Y,"Event")) stop("Expected a 'Event'-object")
+    if (!inherits(Y, "Event")) stop("Expected a 'Event'-object, with codes for terminal events (death.code if any), censoring (cens.code), and event of interest (cause)")
     if (ncol(Y)==2) {
         exit <- Y[,1]
-        entry <- NULL ## rep(0,nrow(Y))
+        entry <- rep(0,nrow(Y))
         status <- Y[,2]
     } else {
         entry <- Y[,1]
         exit <- Y[,2]
         status <- Y[,3]
     }
+    ## default version of codes, otherwise call recregN directly
+    all.codes <-  unique(status)
+    codes <- c(cause,cens.code) 
+    if (!is.null(no.codes)) codes <- c(codes,no.codes) 
+    mcodes <- match(codes,all.codes,nomatch=0)
+    death.code <- all.codes[-mcodes]
+
+    cif <- recreg(formula,data,propodds=propodds,cause=cause,cens.code=cens.code,death.code=death.code,...)
+    class(cif) <- c("cifreg","phreg")
+    cif$call <- cl
+return(cif)
+} # }}}
+
+##' @export
+cifregFG  <- function(formula,data,propodds=NULL,...)
+{# {{{
+cif <- cifreg(formula,data,propodds=propodds,...)
+return(cif)
+} # }}}
+
+##' @export
+IIDbaseline.cifreg <- function(x,...)
+{# {{{
+   out <- IIDbaseline.recreg(x,...)
+   return(out)
+} # }}}
+
+##' @export
+cifregO <- function(formula,data=data,cause=1,cens.code=0,cens.model=~1,weights=NULL,offset=NULL,Gc=NULL,propodds=1,...)
+{ # {{{
+    cl <- match.call() # {{{
+    m <- match.call(expand.dots = TRUE)[1:3]
+    special <- c("strata", "cluster", "offset")
+    Terms <- terms(formula, special, data = data)
+    m$formula <- Terms
+    m[[1]] <- as.name("model.frame")
+    m <- eval(m, parent.frame())
+    Y <- model.extract(m, "response")
+    if (!inherits(Y, "Event")) stop("Expected a 'Event'-object")
+    if (ncol(Y) == 2) {
+        exit <- Y[, 1]
+        entry <- NULL ## rep(0,nrow(Y))
+        status <- Y[, 2]
+    } else {
+        entry <- Y[, 1]
+        exit <- Y[, 2]
+        status <- Y[, 3]
+    }
     id <- strata <- NULL
     if (!is.null(attributes(Terms)$specials$cluster)) {
         ts <- survival::untangle.specials(Terms, "cluster")
         pos.cluster <- ts$terms
-        Terms  <- Terms[-ts$terms]
+        Terms <- Terms[-ts$terms]
         id <- m[[ts$vars]]
-    } else pos.cluster <- NULL
+    } else {
+        pos.cluster <- NULL
+    }
     if (!is.null(stratapos <- attributes(Terms)$specials$strata)) {
         ts <- survival::untangle.specials(Terms, "strata")
         pos.strata <- ts$terms
-        Terms  <- Terms[-ts$terms]
+        Terms <- Terms[-ts$terms]
         strata <- m[[ts$vars]]
         strata.name <- ts$vars
-    }  else { strata.name <- NULL; pos.strata <- NULL}
+    } else {
+        strata.name <- NULL
+        pos.strata <- NULL
+    }
     if (!is.null(offsetpos <- attributes(Terms)$specials$offset)) {
         ts <- survival::untangle.specials(Terms, "offset")
-        Terms  <- Terms[-ts$terms]
+        Terms <- Terms[-ts$terms]
         offset <- m[[ts$vars]]
     }
     X <- model.matrix(Terms, m)
-    if (!is.null(intpos  <- attributes(Terms)$intercept))
-        X <- X[,-intpos,drop=FALSE]
-    if (ncol(X)==0) X <- matrix(nrow=0,ncol=0)
+    if (!is.null(intpos <- attributes(Terms)$intercept)) {
+        X <- X[, -intpos, drop = FALSE]
+    }
+    if (ncol(X) == 0) X <- matrix(nrow = 0, ncol = 0)
 
     ## }}}
 
-    res <- c(cifreg01(data,X,exit,status,id,strata,offset,weights,strata.name,
-                      cens.model=cens.model,
-                      cause=cause,cens.code=cens.code,Gc=Gc,propodds=propodds,...),
-             list(call=cl,model.frame=m,formula=formula,strata.pos=pos.strata,
-                  cluster.pos=pos.cluster,n=nrow(X),nevent=sum(status==cause))
-             )
+    res <- c(
+        cifreg01(data, X, exit, status, id, strata, offset, weights, strata.name,
+            cens.model = cens.model,
+            cause = cause, cens.code = cens.code, Gc = Gc, propodds = propodds, ...
+        ),
+        list(
+            call = cl, model.frame = m, formula = formula, strata.pos = pos.strata,
+            cluster.pos = pos.cluster, n = nrow(X), nevent = sum(status == cause)
+        )
+    )
 
-    class(res) <- c("phreg","cifreg")
+    class(res) <- c("cifreg", "phreg")
     return(res)
-}# }}}
+} # }}}
 
 cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=NULL,
               strata.name=NULL,beta,stderr=TRUE,method="NR",no.opt=FALSE,propodds=1,profile=0,
-              case.weights=NULL,cause=1,cens.code=0,Gc=NULL,cens.model=~+1,augmentation=0,cox.prep=FALSE,...) {# {{{
+              case.weights=NULL,cause=1,cens.code=0,Gc=NULL,cens.model=~+1,augmentation=0,cox.prep=FALSE,
+	      adm.cens.code=NULL,adm.cens.time=NULL,...) {# {{{
     ##  setting up weights, strata, beta and so forth before the action starts# {{{
     p <- ncol(X)
     if (missing(beta)) beta <- rep(0,p)
     if (p==0) X <- cbind(rep(0,length(exit)))
 
-    cause.jumps <- which(status==cause)
+    cause.jumps <- which(status %in% cause)
     max.jump <- max(exit[cause.jumps])
-    other <- which((!(status %in% c(cens.code,cause)) ) & (exit< max.jump))
+    other <- which((!(status %in% c(cens.code,cause,adm.cens.code)) ) & (exit< max.jump))
 
     entry <- NULL
     n <- length(exit)
@@ -178,9 +238,9 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
     ## }}}
 
     ### censoring weights constructed
-    whereC <- which(status==cens.code)
+    whereC <- which(status %in% cens.code)
     time <- exit
-    statusC <- (status==cens.code)
+    statusC <- (status %in% cens.code)
     data$id <- id
     data$exit <- exit
     data$statusC <- statusC
@@ -214,11 +274,10 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
 	cens.strata <- rep(0,length(exit))
     }# }}}
 
-
-    Zcall <- cbind(status,cens.strata,Stime) ## to keep track of status and Censoring strata
-    ## setting up all jumps of type "cause", need S0, S1, S2 at jumps of "cause"
-    stat1 <- 1*(status==cause)
     trunc <- FALSE
+    Zcall <- cbind(status,cens.strata,Stime,adm.cens.time) ## to keep track of status and Censoring strata
+    ## setting up all jumps of type "cause", need S0, S1, S2 at jumps of "cause"
+    stat1 <- 1*(status %in% cause)
     xx2 <- .Call("FastCoxPrepStrata",entry,exit,stat1,X,id,trunc,strata,weights,offset,Zcall,case.weights,PACKAGE="mets")
     xx2$nstrata <- nstrata
     jumps <- xx2$jumps+1
@@ -233,12 +292,13 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
             Gts <- vecAllStrata(cens.model$cumhaz[,2],cens.model$strata.jump,cens.model$nstrata)
             ### back to km product-limit form
             Gts <- apply(rbind(0,Gts),2,diff)
+            if (is.null(dim(Gts))) Gts <- matrix(Gts,1,1)
             ### back to km
             Gts <- suppressWarnings(apply(Gts,2,function(x) exp(cumsum(log(1-x)))))
             Gts <- rbind(1,Gts)[whereaJ,]
             Gts[is.na(Gts)] <- 0
             Gjumps <- Gts
-        } else Gts <- Gjumps <- c(1,Pcens.model$surv)[fast.approx(c(0,Pcens.model$time),jumptimes)]
+        } else Gts <- Gjumps <- c(1,Pcens.model$surv)[fast.approx(c(0,Pcens.model$time),jumptimes,type="left")]
     } else {
         Gts <-   Gjumps <- rep(1,length(jumptimes))
     }
@@ -247,7 +307,9 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
     if (length(other)>=1) {# {{{
         trunc <- TRUE
         weightso <- weights[other]/Stime[other]
+        if (is.null(adm.cens.time))
         timeoo <- rep(max(exit)+1,length(other))
+        else timeoo <- adm.cens.time[other] 
         statuso <- rep(1,length(other))
         Xo <- X[other,,drop=FALSE]
         offseto <- offset[other]
@@ -337,7 +399,8 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
 
         Ut <- caseweightsJ*weightsJ*U
         ## E^2, as n x (pxp)
-        Et2 <-  .Call("vecMatMat",E,E,PACKAGE="mets")$vXZ
+###        Et2 <-  .Call("vecMatMat",E,E,PACKAGE="mets")$vXZ
+        Et2  <- .Call("vecCPMat",E)$XX
         S2S0 <-  (S2oo+S2no)/S0
         DUt <-  -(S2S0-Et2)
 
@@ -345,7 +408,8 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
             Ut  <- pow*Ut
             S0 <- S0/pow
             DUt <- pow*DUt
-            DUt <- DUt+DUadj
+            DUt <-  .Call("XXMatFULL",DUt,p,PACKAGE="mets")$XXf
+	    if (ncol(DUt)>0) DUt <- DUt+DUadj
             if (profile==1) {
 		Ut <- Ut+c(ploglik)*Dwbeta
 		## not implemented
@@ -356,14 +420,25 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
 
         U  <- apply(Ut,2,sum)
         DUt <- caseweightsJ*weightsJ*DUt
-        DU <- -matrix(apply(DUt,2,sum),p,p)
+	if (ncol(DUt)!=p*p) {
+        DU <- matrix(0,p,p);
+        DU[lower.tri(DU,diag=TRUE)] <- -apply(DUt,2,sum)
+        DU<- DU+t(DU)
+        diag(DU) <- diag(DU)/2
+	} else  DU <- -matrix(apply(DUt,2,sum),p,p)
         ploglik <- sum(ploglik)
         U <- U+augmentation
 
         out <- list(ploglik=ploglik,gradient=U,hessian=-DU,cox.prep=xx2,
-                    hessiantime=DUt,weightsJ=weightsJ,caseweightsJ=caseweightsJ,
-                    jumptimes=jumptimes,strata=strataJ,nstrata=nstrata,
-                    time=jumptimes,S0=S0/(caseweightsJ*weightsJ),S2S0=S2S0,E=E,U=Ut,X=Xj,Gjumps=Gjumps)
+                    hessiantime=DUt,weightsJ=weightsJ,
+		    caseweightsJ=caseweightsJ,
+                    jumptimes=jumptimes,
+		    strata.jumps=strataJ,
+		    strata=strataJ,
+		    nstrata=nstrata,
+                    time=jumptimes,
+		    S0=S0/(caseweightsJ*weightsJ),
+		    S2S0=S2S0,E=E,U=Ut,X=Xj,Gjumps=Gjumps)
 
 
         if (all)
@@ -422,10 +497,10 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
     mid <- max(xx2$id)
     UU <- apply(MGt,2,sumstrata,xx2$id,mid+1)
 
+    if (is.null(adm.cens.time)) {
     if (length(other)>=1) { ## martingale part for type-2 after T
-
     ### xx2 data all data
-        otherxx2 <- which(!(xx2$Z[,1] %in% c(cause,cens.code)))
+        otherxx2 <- which(!(xx2$Z[,1] %in% c(cause,cens.code,adm.cens.code)))
         rr0 <- xx2$sign
         jumpsC <-  which(xx2$Z[,1] %in% cens.code)
         strataCxx2 <- xx2$Z[,2]
@@ -453,16 +528,57 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
         UU2 <- apply(MGt2,2,sumstrata,xx2$id[otherxx2],mid+1)
         UU  <-  UU+UU2
     }
+    }
+
+    if (!is.null(adm.cens.time)) {
+    if (length(other)>=1) { ## martingale part for type-2 after T
+        otherxx2 <- which(!(xx2$Z[,1] %in% c(cause,cens.code,adm.cens.code)))
+        rr0 <- xx2$sign
+        jumpsC <-  which(xx2$Z[,1] %in% cens.code)
+        strataCxx2 <- xx2$Z[,2]
+        S0iC2  <-  S0iC <- rep(0,length(xx2$status))
+        S0rrr <- revcumsumstrata(rr0,strataCxx2,nCstrata)
+        S0iC[jumpsC] <- 1/S0rrr[jumpsC]
+        S0iC2[jumpsC] <- 1/S0rrr[jumpsC]^2
+        Gcxx2 <- exp(cumsumstrata(log(1-S0iC),strataCxx2,nCstrata))
+        Gstart <- rep(1,nCstrata)
+
+        dstrata <- mystrata(data.frame(strataCxx2,xx2$strata))
+        ndstrata <- attr(dstrata,"nlevel")
+        lastt <- tailstrata(dstrata-1,ndstrata)
+	if (!is.null(adm.cens.time)) {
+            act <- xx2$Z[otherxx2,4] 
+	    dact <- dstrata[otherxx2]
+            wherea <- indexstratarightR(xx2$time,dstrata-1,act,dact-1,ndstrata,type="left")
+	} else wherea <- lastt[dstrata][otherxx2]
+        ll <-  cumsum2strata(Gcxx2,S0i,strataCxx2,nCstrata,xx2$strata,xx2$nstrata,Gstart)
+        Htsj <- ll$res[wherea]-ll$res[otherxx2]
+        fff <- function(x) {
+            cx  <- cumsum2strata(Gcxx2,x*S0i,strataCxx2,nCstrata,xx2$strata,xx2$nstrata,Gstart)
+            cx <- cx$res[wherea]-cx$res[otherxx2]
+            return(cx)
+        }
+        EHtsj  <- apply(E,2,fff)
+        rrx2 <- rr[otherxx2]*xx2$weights[otherxx2]/xx2$Z[otherxx2,3]
+        MGt2  <- -(Z[otherxx2,,drop=FALSE]*Htsj-EHtsj)*rrx2
+        UU2 <- apply(MGt2,2,sumstrata,xx2$id[otherxx2],mid+1)
+        UU  <-  UU+UU2
+    }
+    }
     ## }}}
 
-    if ((length(other)>=1) & (length(whereC)>0)) { ### Censoring adjustment for jumps of other type but only for KM-case {{{
 
-        Xos <- matrix(0,nrow(Z),ncol(Z));
+    if ((length(other)>=1) & (length(whereC)>0) & (is.null(adm.cens.time))) { ### Censoring adjustment for jumps of other type but only for KM-case {{{
+
+        EHtsja <- Xos <- matrix(0,nrow(Z),ncol(Z));
         Xos[otherxx2,] <- Z[otherxx2,]*rrx2
         rrx <- rep(0,nrow(Z))
         rrx[otherxx2] <- rrx2
         rrsx <- cumsumstrata(rrx,strataCxx2,nCstrata)
         Xos <- apply(Xos,2,cumsumstrata,strataCxx2,nCstrata)
+	Htsja <- rep(0,nrow(Z))
+###	Htsja[otherxx2] <- Htsj
+###	EHtsja[otherxx2,] <- EHtsj
         q2 <- (Xos*c(Htsj)-EHtsj*c(rrsx))
 
         sss <- headstrata(dstrata-1,ndstrata)
@@ -495,14 +611,23 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
         DLambeta.t <- apply(opt$E/c(opt$S0),2,cumsumstrata,strata,nstrata)
         varbetat <-   rowSums((DLambeta.t %*% iH)*DLambeta.t)
     } else varbetat <- 0
-    var.cumhaz <- cumsumstrata(1/opt$S0^2,strata,nstrata)+varbetat
+    wwJ <- opt$caseweightsJ*opt$weightsJ
+    var.cumhaz <- cumsumstrata(1/(opt$S0^2*wwJ),strata,nstrata)+varbetat
     se.cumhaz <- cbind(jumptimes,(var.cumhaz)^.5)
     colnames(se.cumhaz) <- c("time","se.cumhaz")
 
 
+  if (!is.null(Uiid)) {
+     colnames(Uiid) <- names(beta.s)
+     if (nrow(Uiid) == nrow(data)) rownames(Uiid) <- rownames(data)
+  }
+
     out <- list(coef=beta.s,var=varmc,se.coef=diag(varmc)^.5,iid.naive=UUiid,
                 iid=Uiid,ncluster=nid,
-                ihessian=iH,hessian=opt$hessian,var1=var1,se1.coef=diag(var1)^.5,
+                ihessian=iH,hessian=opt$hessian,
+		hessianttime=opt$hessiantime,
+		strata.jumps=opt$strata.jumps,
+		var1=var1,se1.coef=diag(var1)^.5,
                 ploglik=opt$ploglik,gradient=opt$gradient,
                 cumhaz=cumhaz, se.cumhaz=se.cumhaz,MGciid=MGc,
 		strata.call=strata.call,
@@ -521,27 +646,112 @@ cifreg01 <- function(data,X,exit,status,id=NULL,strata=NULL,offset=NULL,weights=
 }# }}}
 
 ##' @export
-indexstratarightR <- function(timeo,stratao,jump,js,nstrata,type="right")# {{{
-{
-  if (any(stratao<0 | stratao>=nstrata)) stop("time-strata strata not between 0-(nstrata-1)\n")
-  if (any(js<0 | js>=nstrata)) stop("jump-strata strata not between 0-(nstrata-1)\n")
-  mm <- cbind(timeo,stratao,1:length(timeo),0)
-  mm <- rbind(mm,cbind(jump,js,1:length(jump),1))
-  ord <- order(mm[,1],mm[,4])
-  mm <- mm[ord,]
-  if (type=="right") right <- 1 else right <- 0
-  res <- .Call("indexstrataR",mm[,2],mm[,3],mm[,4],nstrata,right)$res[,1]
-  if (right==0) res <- rev(res)
+IC.cifreg <- function(x, ...) {# {{{
+  res <- with(x, iid * NROW(iid))
   return(res)
+}
+# }}}
+
+##' @export
+plot.cifreg <- function(x,se=FALSE,ylab=NULL,...) { ## {{{
+   if (inherits(x,"cifreg") & is.null(ylab)) ylab <- "Cumulative Hazard"
+if (!se) baseplot(x,se=se,ylab=ylab,...)
+else {
+    warning("Standard errors approximative (but too small), use predict and type='cumhaz' \n")
+    baseplot(x,se=se,ylab=ylab,...)
+}
+} ## }}}
+
+##' @export
+predict.cifreg <- function(object,newdata,se=FALSE,times=NULL,np=50,...) { ## {{{
+if (!is.null(object$propodds) & se) {se <- FALSE; warning("standard errors not computed for logit link\n"); }
+if (!se) out <- predict.phreg(object,newdata,se=se,times=times,...)
+else {
+  out <- predictrecreg(object,newdata,times=times,np=np,...)
+}
+class(out) <- c("predictcifreg",class(object)[1])
+return(out)
+} ## }}}
+
+##' @export
+summary.predictcifreg <- function(object,times=NULL,type=c("cif","cumhaz","surv")[1],...) {# {{{
+ret <- summary.predictrecreg(object,type=type[1],times=times,...)
+return(ret)
 }# }}}
 
 ##' @export
-iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
+plot.predictcifreg <- function(x,se=FALSE,ylab=NULL,type="cif",...)
+{ ## {{{
+  if (inherits(x,"predictcifreg") & is.null(ylab)) ylab <- "Probability"
+  plotpredictphreg(x,se=se,ylab=ylab,type=type[1],...)
+} ## }}}
+
+##' @export
+gofFG <- function(formula,data,cause=1,cens.code=0,cens.model=NULL,...)
+{# {{{
+fgform <- update(formula, paste("Surv(fgstart, fgstop, fgstatus) ~ .+cluster(id)"))
+## assumes simple Surv(time,status) is given 
+vars <- all.vars(formula)
+data$id <- 1:nrow(data)
+formid <- update.formula(formula,paste(".~.+id"))
+
+## process types to get type of interst and other types 
+status <- data[,vars[2]]
+types <- unique(status)
+mm <- match(c(cens.code,cause),types)
+mm <- mm[!is.na(mm)]
+statusS <- status
+statusS[!(status %in% c(cens.code,cause))] <- types[-mm][1]
+typesF <- c(cens.code,cause,types[-mm][1])
+###
+###data[,vars[2]] <- factor(statusS,typesF,c("censoring","cause","ocause"))
+data[,vars[2]] <- factor(statusS,typesF,typesF)
+
+Xs <- vars[-(1:2)]
+modP <- paste(Xs,collapse="+") 
+formid <- as.formula(paste("Surv(",vars[1],",",vars[2],")~",modP,"+id"))
+if (!is.null(cens.model)) {
+Cstrata <- as.character(cens.model)
+formid <- as.formula(paste("Surv(",vars[1],",",vars[2],")~",modP,"+",Cstrata[2],"+id"))
+}
+
+fgdata <- finegray(formid,data=data)
+fgcph <- phreg(fgform,data=fgdata,weights=fgdata$fgwt,...)
+ggmg <- gof(fgcph)
+return(ggmg)
+}# }}}
+
+##' @export
+indexstratarightR <- function(timeo,stratao,jump,js,nstrata,type="right")# {{{
+{
+###    if (any(stratao < 0 | stratao >= nstrata))
+###        stop("time-strata strata not between 0-(nstrata-1)\n")
+###    if (any(js < 0 | js >= nstrata))
+###        stop("jump-strata strata not between 0-(nstrata-1)\n")
+    mm <- cbind(timeo, stratao, 1:length(timeo), 0)
+    mm <- rbind(mm, cbind(jump, js, 1:length(jump), 1))
+    ord <- order(mm[, 1], mm[, 4])
+    mm <- mm[ord, ]
+    if (type == "right") right <- 1 else right <- 0
+    ires <- .Call("indexstrataR", mm[, 2], mm[, 3], mm[, 4], nstrata,right)
+    res <- ires$res
+    or2 <- order(res[,2])
+    res <- res[or2,1]
+    reso <- which(res==0) 
+    if (length(reso)>0) {
+       jso <- js[reso]
+       for (s in 1:nstrata) if (length(jso)>0) res[reso[jso==s-1]] <- ires$maxmin[s] 
+    }
+    return(res)
+} ## }}}
+
+##' @export IIDbaseline.cifreg 
+IIDbaseline.cifregO <- function(x,time=NULL,fixbeta=NULL,...)
 {# {{{
 ###  sum_i int_0^t 1/S_0(s) dM_{ki}(s) - P(t) \beta_k
 ###  with possible strata and cluster "k", and i in clusters 
   if (length(class(x))!=2) stop("Must be cifreg object\n"); 
-  if (!inherits(x,c("cifreg","recreg"))) stop("Must be cifreg object\n"); 
+  if (!inherits(x,c("cifreg","recreg"))) stop("Must be cifreg/recreg object\n"); 
   if (is.null(time)) stop("Must give time for iid of baseline")
 
   if (!is.null(x$propodds))  stop("Only for Fine-Gray-model") 
@@ -601,7 +811,8 @@ iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
 
     MGAiid <- NULL
     S0i2 <- rep(0,length(xx2$strata))
-    S0i2[jumps] <- 1/x$S0^2
+    ww <- xx2$caseweights*xx2$weights
+    S0i2[jumps] <- 1/(x$S0^2*ww[jumps])
     MGAiid <- matrix(0,length(S0i2),1)
     MGAiid2 <- matrix(0,length(S0i2),1)
     cumhazAA <- cumsumstrata(S0i2*btimexx,xx2$strata,xx2$nstrata)
@@ -694,7 +905,8 @@ iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
  for (i in sus)  { 
 	 wi <- which(xx2$strata==i)
          MGAiidl <- sumstrata(MGAiid[wi],xx2$id[wi],mid+1)
-	 cumhaz.time <- c(cumhaz.time,Cpred(x$cumhaz[x$strata[x$jumps]==i,],time)[,-1])
+	 cumhazs <- x$cumhaz[x$strata[x$jumps]==i,,drop=FALSE]
+cumhaz.time <- c(cumhaz.time,cpred(rbind(0,cumhazs),time)[,2])
 
         if (fixbeta==0) {
            UU <-  apply(HtS[i+1,]*t(betaiid),2,sum)
@@ -713,8 +925,9 @@ iid.baseline.cifreg <- function(x,time=NULL,fixbeta=NULL,...)
 	     model.frame=x$model.frame,formula=x$formula))
 } # }}}
 
+
 ##' @export
-FGprediid <- function(iidBase,newdata,conf.type=c("log","cloglog","plain"))
+FGprediid <- function(iidBase,newdata,conf.type=c("log","cloglog","plain"),model="FG")
 {# {{{
   des <- readPhreg(iidBase,newdata)
   strata <- des$strata
@@ -722,17 +935,23 @@ FGprediid <- function(iidBase,newdata,conf.type=c("log","cloglog","plain"))
 	  fixbeta <- 0; beta.iid <- iidBase$beta.iid; X <- des$X; p <- ncol(beta.iid); 
   } else { fixbeta <- 1; beta.iid <- 0; X <- matrix(0,1,1); p <- 1 }
 
-   sus <- sort(unique(strata))
-
-   At <- iidBase$cumhaz.time[match(sus,iidBase$strata.time)]
+  sus <- sort(unique(strata))
+  At <- iidBase$cumhaz.time[match(sus,iidBase$strata.time)]
 
    if (missing(X)) X <- matrix(0,1,p)
    if (ncol(X)!=p) stop("X and coef does not match \n"); 
 
-   Ft <- function(p,Xi=rep(0,length(p)-1),type="log") {
-       if (type=="log")     y <- log(1-exp(-p[1]*exp(sum(Xi*p[-1]))))
-       if (type=="plain")   y <- 1-exp(-p[1]*exp(sum(Xi*p[-1])))
-       if (type=="cloglog") y <- log(-log(1-exp(-p[1]*exp(sum(Xi*p[-1])))))
+   Ft <- function(coef,Xi=rep(0,length(p)),type="log") {
+	   base <- coef[1]
+	   p <- coef[-1]
+   if (model=="FG") {
+       if (type=="log")     y <- log(1-exp(-base*exp(Xi %*% p)))
+       if (type=="plain")   y <- 1-exp(-base*exp(Xi %*% p))
+       if (type=="cloglog") y <- log(-log(1-exp(-base*exp(Xi %*% p))))
+   } else { ## Ghosh-Lin model
+       if (type=="log")     y <- log(base*exp(Xi %*% p))
+       if (type=="plain")   y <- base*exp(Xi %*% p)
+   }
        return(y)
    }
    Ftback <- function(p,type="log")
@@ -782,7 +1001,7 @@ return(preds)
 }# }}}
 
 ##' @export
-strataC <- survival:::strata
+strataC <- survival::strata
 
 ##' Augmentation for Fine-Gray model based on stratified NPMLE Cif (Aalen-Johansen)
 ##'
@@ -978,8 +1197,8 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
     xxstatus  <- dd$Z[,1]
     xxstrata  <- dd$Z[,2]
     other <- which((!(xxstatus %in% c(cens.code,cause)) ) )
-    jumps1 <- which(xxstatus==cause)
-    jumpsD <- which(xxstatus!=cens.code)
+    jumps1 <- which(xxstatus %in% cause)
+    jumpsD <- which(!(xxstatus %in% cens.code))
     rr <- c(dd$sign*exp(dd$offset))
     ## S0 after strata
     S0 = c(revcumsumstrata(rr,xxstrata,nstrata))
@@ -1113,7 +1332,6 @@ FG_AugmentCifstrata <- function(formula,data=data,E=NULL,cause=NULL,cens.code=0,
     return(fga)
 }# }}})
 
-
 ##' @export
 simul.cifs <- function(n,rho1,rho2,beta,rc=0.5,depcens=0,rcZ=0.5,bin=1,type=c("cloglog","logistic"),rate=1,Z=NULL) {# {{{
     p=length(beta)/2
@@ -1132,7 +1350,7 @@ simul.cifs <- function(n,rho1,rho2,beta,rc=0.5,depcens=0,rcZ=0.5,bin=1,type=c("c
 
     cif1 <- setup.cif(cbind(tt,Lam1),beta[1:p],Znames=colnames(Z),type=type[1])
     cif2 <- setup.cif(cbind(tt,Lam2),beta[(p+1):(2*p)],Znames=colnames(Z),type=type[1])
-    data <- timereg::sim.cifsRestrict(list(cif1,cif2),n,Z=Z)
+    data <- sim.cifsRestrict(list(cif1,cif2),n,Z=Z)
 
     if (depcens==0) censor=pmin(rexp(n,1)*(1/rc),6) else censor=pmin(rexp(n,1)*(1/(rc*exp(Z %*% rcZ))),6)
 
