@@ -1,3 +1,6 @@
+#' @keywords internal
+"_PACKAGE"
+
 ##' Analysis of Multivariate Events
 ##'
 ##' Implementation of various statistical models for multivariate
@@ -5,7 +8,6 @@
 ##' and bivariate random effects probit models (Liability models)
 ##'
 ##' @name mets-package
-##' @docType package
 ##' @author Klaus K. Holst and Thomas Scheike
 ##' @useDynLib mets, .registration=TRUE
 ##' @import stats splines Rcpp mvtnorm
@@ -15,13 +17,14 @@
 ##'   eventTime Expand getoutcome gof intercept<- Inverse kill<- latent latent<-
 ##'   lava.options lvm Model multigroup parameter<- pars regression regression<-
 ##'   revdiag trim IC expit logit
-##' @importFrom timereg two.stage predict.two.stage sindex.prodlim Cpred Event
-##' @importFrom survival Surv is.Surv concordance strata
+##' @importFrom survival Surv is.Surv concordance strata cluster finegray
+##' @importFrom timereg two.stage predict.two.stage
 ##' @importFrom utils head tail getS3method glob2rx capture.output
 ##' @importFrom graphics matplot lines plot polygon par points abline title
 ##'   matlines legend
+##' @importFrom methods hasArg
 ##' @importFrom grDevices dev.list devAskNewPage dev.interactive
-##' @keywords package
+##' @aliases mets mets-package
 ##' @examples
 ##'
 ##' ## To appear
@@ -31,6 +34,9 @@ NULL
 ##' @export
 lava::IC
 
+##' @export
+lava::iid
+
 ##' @export
 lava::twostage
 
@@ -40,6 +46,15 @@ lava::estimate
 ##' @export
 lava::gof
 
+##' @export
+survival::strata
+
+##' @export
+survival::Surv
+
+##' @export
+survival::cluster
+
 ##' np data set
 ##'
 ##' @name np
@@ -88,6 +103,58 @@ NULL
 ##' fast.reshape(dermalridgesMZ,id="id",varying=c("left","right"))
 NULL
 
+##' CALGB 8923, twostage randomization SMART design
+##'
+##' Data from CALGB 8923 
+##' @name calgb8923 
+##' @docType data
+##' @keywords data
+##' @format Data from smart design
+##' id: id of subject
+##' status : 1-death, 2-response for second randomization, 0-censoring
+##' A0 : treament at first randomization
+##' A1 : treament at second randomization
+##' At.f : treament given at record (A0 or A1)
+##' TR : time of response 
+##' sex : 0-males, 1-females 
+##' consent: 1 if agrees to 2nd randomization, censored if not
+##' R: 1 if response 
+##' trt1: A0
+##' trt2: A1
+##' @source  https://github.com/ycchao/code_Joint_model_SMART
+##' @examples
+##' data(calgb8923)
+NULL
+
+##' ACTG175, block randmized study from speff2trial package
+##'
+##' Data from speff2trial
+##' @name ACTG175
+##' @docType data
+##' @keywords data
+##' @format Randomized study 
+##' @source  Hammer et al. 1996, speff2trial package.
+##' @examples
+##' data(ACTG175)
+NULL
+
+##' hfaction, subset of block randmized study HF-ACtion from WA package  
+##'
+##' Data from HF-action trial slightly modified from WA package,
+##' consisting of 741 nonischemic patients with baseline
+##' cardiopulmonary test duration less than or equal to 12 minutes.
+##' @name hfactioncpx12
+##' @docType data
+##' @keywords data
+##' @format Randomized study 
+##' status : 1-event, 2-death, 0-censoring
+##' treatment : 1/0
+##' @source  WA package, Connor et al. 2009
+##' @examples
+##' data(hfactioncpx12)
+NULL
+
+
 ##' Menarche data set
 ##'
 ##' @name mena
