@@ -148,6 +148,7 @@ RcppExport SEXP FastCoxPrepStrata(SEXP EntrySEXP, SEXP ExitSEXP, SEXP StatusSEXP
         unsigned kj=0;
 
 	//Rcout << "n=" << X.n_rows << ", p=" << X.n_cols << std::endl;
+//	Rcout << "n=" << Z.n_rows << ", p=" << Z.n_cols << std::endl;
 
 	mat XX(n, X.n_cols*(X.n_cols+1)/2); // Calculate XX' at each time-point
 	for (unsigned i=0; i<X.n_rows; i++) {
@@ -164,7 +165,7 @@ RcppExport SEXP FastCoxPrepStrata(SEXP EntrySEXP, SEXP ExitSEXP, SEXP StatusSEXP
 	}
 
 //	unsigned nZ = Z.n_rows;
-//	if (Truncation) nZ = 2*Z.n_rows;
+//	if (Truncation) nZ = 2*nZ;
 	mat ZX(n , Z.n_cols * X.n_cols);
 	if (Z.n_rows==X.n_rows)
 		for (unsigned i=0; i<X.n_rows; i++) {
@@ -220,6 +221,7 @@ RcppExport SEXP FastCoxPrepStrata(SEXP EntrySEXP, SEXP ExitSEXP, SEXP StatusSEXP
 		XX = XX.rows(idx);
 		X = X.rows(idx);
 	}
+
 	if (Z.n_rows==X.n_rows) {
 		Z = Z.rows(idx);
 	}
@@ -506,7 +508,7 @@ RcppExport SEXP DLambetaR(SEXP iweights,SEXP iS0,SEXP iE,SEXP iXi,SEXP istrata,S
 }/*}}}*/
 
 colvec  cumsumstrataAddGam(colvec a,IntegerVector strata,int nstrata, colvec exb,colvec etheta,cube thetades,cube rv,mat ags, uvec Jumps) {/*{{{*/
-	unsigned n = a.n_rows;
+unsigned n = a.n_rows;
 	colvec tmpsum(nstrata);
 	tmpsum.zeros(); tmpsum.zeros();
 	colvec res = a;
@@ -639,6 +641,7 @@ RcppExport SEXP revcumsum2stratafdNR(SEXP ia, SEXP idN, SEXP istrata, SEXP instr
 	return(rres);
 }/*}}}*/
 
+// [[Rcpp::export(name="S0FG")]] 
 RcppExport SEXP S0_FG_GcR(SEXP ia,SEXP iGc,SEXP itype2,SEXP istatus,SEXP istrata,SEXP instrata,SEXP istrata2,SEXP instrata2,SEXP iGcstart) {/*{{{*/
 	colvec a = Rcpp::as<colvec>(ia);
 	colvec Gc = Rcpp::as<colvec>(iGc);
@@ -687,6 +690,82 @@ RcppExport SEXP S0_FG_GcR(SEXP ia,SEXP iGc,SEXP itype2,SEXP istatus,SEXP istrata
 	return(rres);
 }/*}}}*/
 
+
+// [[Rcpp::export(name="Gcjumps")]] 
+RcppExport SEXP GcjumpsR(SEXP iGc,SEXP istatus,SEXP istrata2,SEXP instrata2,SEXP iGcstart,SEXP injumps) {/*{{{*/
+	colvec Gc = Rcpp::as<colvec>(iGc);
+	colvec Gcstart = Rcpp::as<colvec>(iGcstart);
+	IntegerVector status(istatus);
+        IntegerVector strata2(istrata2);
+	unsigned nstrata2 = Rcpp::as<int>(instrata2);
+	unsigned njumps = Rcpp::as<int>(injumps);
+	unsigned n = Gc.n_rows;
+
+       vec Gct(nstrata2); for (unsigned  i=0; i<nstrata2; i++) Gct(i)=Gcstart(i);
+       mat Gcjumps(njumps,nstrata2); 
+       // whenever jump compute S_ss(t) = \sum_c G_c(t) S_ss,c(t) 
+       unsigned jumps=0; 
+       
+	for (unsigned i=0; i<n; i++) {
+		int ss2=strata2(i);
+		Gct(ss2)=Gc(i); 
+		if (status(i)>0) {
+			for (unsigned k=0;k<nstrata2; k++) Gcjumps(jumps,k)=Gct(k); 
+			jumps=jumps+1; 
+	         }
+	}
+
+	List rres;
+	rres["Gcjumps"]=Gcjumps;
+	return(rres);
+}/*}}}*/
+
+
+
+// [[Rcpp::export(name="S0FGN")]] 
+RcppExport SEXP S0_FGRN(SEXP ia,SEXP itype2,SEXP istatus,SEXP istrata,SEXP instrata,SEXP istrata2,SEXP instrata2,SEXP iGcjumps) {/*{{{*/
+	colvec a = Rcpp::as<colvec>(ia);
+//	colvec Gc = Rcpp::as<colvec>(iGc);
+//	colvec Gcstart = Rcpp::as<colvec>(iGcstart);
+	IntegerVector status(istatus);
+	IntegerVector type2(itype2);
+	IntegerVector strata(istrata);
+	unsigned nstrata = Rcpp::as<int>(instrata);
+        IntegerVector strata2(istrata2);
+	unsigned nstrata2 = Rcpp::as<int>(instrata2);
+	unsigned n = a.n_rows;
+	mat Gcjumps = Rcpp::as<mat>(iGcjumps);
+	unsigned njumps = Gcjumps.n_rows;
+
+        vec S0jumps(njumps); 
+        // strata 2 er C-strata,  
+	// first compute S0(nstrata,nstrataC+1) for all time points 
+	// type is 1 when type is other dead, and type  is 0 when normal risk
+	mat tmpsum(nstrata,nstrata2+1); tmpsum.zeros();
+//        mat S0s(n,nstrata2+1); S0s.zeros();
+//	colvec S0sc = a;
+	unsigned jumps=njumps-1; 
+	for (unsigned i=0; i<n; i++) {
+		int ss=strata(n-i-1); 
+		// censureringstrata put to 0 for non type2
+		int ss2=type2(n-i-1)*(strata2(n-i-1)+1);
+		tmpsum(ss,ss2) += a(n-i-1);
+//		S0sc(n-i-1)=tmpsum(ss,ss2);
+		if (status(n-i-1)>0) {
+			for (unsigned k=1;k<nstrata2+1; k++) S0jumps(jumps)+=Gcjumps(jumps,k-1)*tmpsum(ss,k); 
+//		        for (unsigned k=0;k<nstrata2+1; k++) S0s(n-i-1,k)=tmpsum(ss,k); 
+			S0jumps(jumps)+=tmpsum(ss,0); 
+			jumps=jumps-1; 
+		}
+	}
+
+	List rres;
+	rres["S0"]=S0jumps;
+//	rres["S0m"]=S0s;
+	return(rres);
+}/*}}}*/
+
+
 //
 //RcppExport SEXP S0_N_GcR(SEXP ia,SEXP iGc,SEXP itype2,SEXP istatus,SEXP istrata,SEXP instrata,SEXP istrata2,SEXP instrata2,SEXP iGcstart) {/*{{{*/
 //	colvec a = Rcpp::as<colvec>(ia);
@@ -990,13 +1069,14 @@ RcppExport SEXP cumsumstratasumR(SEXP ia,SEXP istrata, SEXP instrata) {/*{{{*/
 	for (unsigned i=0; i<n; i++) {
 		ss=intstrata(i);
 		// valid strata update
-		if ((first>0.1) && (i>=1)&& (ss<nstrata) && (ss>=0))
-			ressqu(i)=ressqu(i-1)+pow(a(i),2)+2*a(i)*tmpsum(ss);
-			lagressum(i)=tmpsum(ss);
-			tmpsum(ss) += a(i);
-			// cumsum+=a(i);
-			if (first<0.1) ressqu(i) = pow(a(i),2);
-			first=1;
+		if ((first>0.1) && (i>=1)&& (ss<nstrata) && (ss>=0)) {
+			ressqu(i) = ressqu(i - 1) + pow(a(i), 2) + 2 * a(i) * tmpsum(ss);
+		}
+		lagressum(i)=tmpsum(ss);
+		tmpsum(ss) += a(i);
+		// cumsum+=a(i);
+		if (first<0.1) ressqu(i) = pow(a(i),2);
+		first=1;
 		ressum(i) = tmpsum(ss);
 	}
 
